#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class tan_source_term(Boolean):
    """
    'tan_source_term' child.
    """

    fluent_name = "tan-source-term"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class max_files(Integer):
    """
    Set the maximum number of data files to save. After the maximum is reached, a file will be deleted for each file saved.
    """

    fluent_name = "max-files"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class axis_direction_component_child(Real):
    """
    'child_object_type' of axis_direction_component.
    """

    fluent_name = "child-object-type"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class total_number_of_time_steps(Integer):
    """
    Set total number of Time steps.
    """

    fluent_name = "total-number-of-time-steps"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .les_spec_name import les_spec_name
from .rfg_number_of_modes import rfg_number_of_modes
from .vm_nvortices import vm_nvortices
from .les_embedded_fluctuations import les_embedded_fluctuations
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'les_spec_name',
         'rfg_number_of_modes', 'vm_nvortices', 'les_embedded_fluctuations']

    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of phase_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of phase_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of phase_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of phase_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of phase_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of phase_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of phase_child.
    """
    les_spec_name: les_spec_name = les_spec_name
    """
    les_spec_name child of phase_child.
    """
    rfg_number_of_modes: rfg_number_of_modes = rfg_number_of_modes
    """
    rfg_number_of_modes child of phase_child.
    """
    vm_nvortices: vm_nvortices = vm_nvortices
    """
    vm_nvortices child of phase_child.
    """
    les_embedded_fluctuations: les_embedded_fluctuations = les_embedded_fluctuations
    """
    les_embedded_fluctuations child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class keep_linearized_source_terms_constant(Boolean):
    """
    Enable/disable keeping linearized DPM source terms constant until the next DPM Update.
    """

    fluent_name = "keep-linearized-source-terms-constant?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable import enable
from .drag_law import drag_law
from .lift_law import lift_law
class particle_rotation(Group):
    """
    'particle_rotation' child.
    """

    fluent_name = "particle-rotation"

    child_names = \
        ['enable', 'drag_law', 'lift_law']

    enable: enable = enable
    """
    enable child of particle_rotation.
    """
    drag_law: drag_law = drag_law
    """
    drag_law child of particle_rotation.
    """
    lift_law: lift_law = lift_law
    """
    lift_law child of particle_rotation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class update_interval_time_step_size(Integer):
    """
    Set Time Step Size Update Interval.
    """

    fluent_name = "update-interval-time-step-size"




#
# This is an auto-generated file.  DO NOT EDIT!
#

"""A package providing Fluent's Settings Objects in Python."""
from ansys.fluent.core.solver.flobject import *

SHASH = "df272d2f2ae3d31ee8ca1662188a1ddc1aa5dffb6a23ffde3837250dcc80eeeb"
from .root import root


#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .change_type import change_type
from .radiator_child import radiator_child

class radiator(NamedObject[radiator_child], _CreatableNamedObjectMixin[radiator_child]):
    """
    'radiator' child.
    """

    fluent_name = "radiator"

    command_names = \
        ['change_type']

    change_type: change_type = change_type
    """
    change_type command of radiator.
    """
    child_object_type: radiator_child = radiator_child
    """
    child_object_type of radiator.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class rel_vel_resistance(Boolean):
    """
    'rel_vel_resistance' child.
    """

    fluent_name = "rel-vel-resistance?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .from_zone_type import from_zone_type
from .from_zone_name import from_zone_name
from .phase_25 import phase
class compute(Command):
    """
    'compute' command.
    
    Parameters
    ----------
        from_zone_type : str
            'from_zone_type' child.
        from_zone_name : str
            'from_zone_name' child.
        phase : str
            'phase' child.
    
    """

    fluent_name = "compute"

    argument_names = \
        ['from_zone_type', 'from_zone_name', 'phase']

    from_zone_type: from_zone_type = from_zone_type
    """
    from_zone_type argument of compute.
    """
    from_zone_name: from_zone_name = from_zone_name
    """
    from_zone_name argument of compute.
    """
    phase: phase = phase
    """
    phase argument of compute.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .piecewise_linear_child import piecewise_linear_child

class piecewise_linear(ListObject[piecewise_linear_child]):
    """
    'piecewise_linear' child.
    """

    fluent_name = "piecewise-linear"

    child_object_type: piecewise_linear_child = piecewise_linear_child
    """
    child_object_type of piecewise_linear.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .pressure_outlet_child import pressure_outlet_child

class pressure_outlet(NamedObject[pressure_outlet_child], _NonCreatableNamedObjectMixin[pressure_outlet_child]):
    """
    'pressure_outlet' child.
    """

    fluent_name = "pressure-outlet"

    child_object_type: pressure_outlet_child = pressure_outlet_child
    """
    child_object_type of pressure_outlet.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .axis_direction_child import axis_direction_child

class global_dt_pseudo_relax(NamedObject[axis_direction_child], _NonCreatableNamedObjectMixin[axis_direction_child]):
    """
    'global_dt_pseudo_relax' child.
    """

    fluent_name = "global-dt-pseudo-relax"

    child_object_type: axis_direction_child = axis_direction_child
    """
    child_object_type of global_dt_pseudo_relax.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class options_length_scale_calc_methods(String):
    """
    Length Scale Calculation Method.
    """

    fluent_name = "options-length-scale-calc-methods"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .offset import offset
class translate(Command):
    """
    Translate the mesh.
    
    Parameters
    ----------
        offset : typing.Tuple[real, real, real]
            'offset' child.
    
    """

    fluent_name = "translate"

    argument_names = \
        ['offset']

    offset: offset = offset
    """
    offset argument of translate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class include_convective_heat_transfer(Boolean):
    """
    Enable/disable convection/conduction in the film-to-wall heat transfer model.
    """

    fluent_name = "include-convective-heat-transfer?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class linear_growth_of_dpm_source_terms(Boolean):
    """
    Enable/disable the linear growth of DPM source terms every DPM iteration.
    """

    fluent_name = "linear-growth-of-dpm-source-terms?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .constant_1 import constant
from .variable_1 import variable
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['option', 'constant', 'variable']

    option: option = option
    """
    option child of options.
    """
    constant: constant = constant
    """
    constant child of options.
    """
    variable: variable = variable
    """
    variable child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .data_sampling import data_sampling
from .sampling_interval import sampling_interval
from .statistics_shear_stress import statistics_shear_stress
from .statistics_heat_flux import statistics_heat_flux
from .wall_statistics import wall_statistics
from .force_statistics import force_statistics
from .time_statistics_dpm import time_statistics_dpm
from .species_list import species_list
from .statistics_mixture_fraction import statistics_mixture_fraction
from .statistics_reaction_progress import statistics_reaction_progress
from .save_cff_unsteady_statistics import save_cff_unsteady_statistics
from .setup_unsteady_statistics import setup_unsteady_statistics
class data_sampling(Group):
    """
    'data_sampling' child.
    """

    fluent_name = "data-sampling"

    child_names = \
        ['data_sampling', 'sampling_interval', 'statistics_shear_stress',
         'statistics_heat_flux', 'wall_statistics', 'force_statistics',
         'time_statistics_dpm', 'species_list', 'statistics_mixture_fraction',
         'statistics_reaction_progress', 'save_cff_unsteady_statistics']

    data_sampling: data_sampling = data_sampling
    """
    data_sampling child of data_sampling.
    """
    sampling_interval: sampling_interval = sampling_interval
    """
    sampling_interval child of data_sampling.
    """
    statistics_shear_stress: statistics_shear_stress = statistics_shear_stress
    """
    statistics_shear_stress child of data_sampling.
    """
    statistics_heat_flux: statistics_heat_flux = statistics_heat_flux
    """
    statistics_heat_flux child of data_sampling.
    """
    wall_statistics: wall_statistics = wall_statistics
    """
    wall_statistics child of data_sampling.
    """
    force_statistics: force_statistics = force_statistics
    """
    force_statistics child of data_sampling.
    """
    time_statistics_dpm: time_statistics_dpm = time_statistics_dpm
    """
    time_statistics_dpm child of data_sampling.
    """
    species_list: species_list = species_list
    """
    species_list child of data_sampling.
    """
    statistics_mixture_fraction: statistics_mixture_fraction = statistics_mixture_fraction
    """
    statistics_mixture_fraction child of data_sampling.
    """
    statistics_reaction_progress: statistics_reaction_progress = statistics_reaction_progress
    """
    statistics_reaction_progress child of data_sampling.
    """
    save_cff_unsteady_statistics: save_cff_unsteady_statistics = save_cff_unsteady_statistics
    """
    save_cff_unsteady_statistics child of data_sampling.
    """
    command_names = \
        ['setup_unsteady_statistics']

    setup_unsteady_statistics: setup_unsteady_statistics = setup_unsteady_statistics
    """
    setup_unsteady_statistics command of data_sampling.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class zero_nodal_velocities_on_walls(Boolean):
    """
    Enable/disable setting the nodal velocity on all walls to zero.
    """

    fluent_name = "zero-nodal-velocities-on-walls?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class two_dim_space(String):
    """
    'two_dim_space' child.
    """

    fluent_name = "two-dim-space"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class next_view(Command):
    """
    Return to the camera position after the current position in the stack.
    """

    fluent_name = "next-view"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class low_pressure_boundary_slip(Boolean):
    """
    Enable/disable the slip boundary formulation for low-pressure gas systems.
    """

    fluent_name = "low-pressure-boundary-slip?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class rhie_chow_method(Integer):
    """
    Enter the rhie-chow flux method.
    """

    fluent_name = "rhie-chow-method"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .value1 import value1
from .value2 import value2
class except_in_range(Group):
    """
    'except_in_range' child.
    """

    fluent_name = "except-in-range"

    child_names = \
        ['value1', 'value2']

    value1: value1 = value1
    """
    value1 child of except_in_range.
    """
    value2: value2 = value2
    """
    value2 child of except_in_range.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class alternate_bc_formulation(Boolean):
    """
    Enable/disable use of alternate compressible bc formulation.
    """

    fluent_name = "alternate-bc-formulation?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class max_cycle(Integer):
    """
    Coupled:maximum number of cycles.
    """

    fluent_name = "max-cycle"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class beach_end_point(Real):
    """
    'beach_end_point' child.
    """

    fluent_name = "beach-end-point"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class false_time_step_linearization(Boolean):
    """
    Set false time-step linearization for added stability.
    """

    fluent_name = "false-time-step-linearization?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class tracking_statistics_format(Integer):
    """
    Control the format of the one-line tracking statistics printed after every DPM tracking pass.
    """

    fluent_name = "tracking-statistics-format"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .node_values import node_values
from .position_on_x_axis import position_on_x_axis
from .position_on_y_axis import position_on_y_axis
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['node_values', 'position_on_x_axis', 'position_on_y_axis']

    node_values: node_values = node_values
    """
    node_values child of options.
    """
    position_on_x_axis: position_on_x_axis = position_on_x_axis
    """
    position_on_x_axis child of options.
    """
    position_on_y_axis: position_on_y_axis = position_on_y_axis
    """
    position_on_y_axis child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .energy import energy
from .multiphase import multiphase
from .viscous import viscous
class models(Group):
    """
    'models' child.
    """

    fluent_name = "models"

    child_names = \
        ['energy', 'multiphase', 'viscous']

    energy: energy = energy
    """
    energy child of models.
    """
    multiphase: multiphase = multiphase
    """
    multiphase child of models.
    """
    viscous: viscous = viscous
    """
    viscous child of models.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class mc_poldfun_p(Boolean):
    """
    'mc_poldfun_p' child.
    """

    fluent_name = "mc-poldfun-p?"

